@@ -4,8 +4,7 @@ import time
 from colorama import Fore, Style
 
 class Loader:
-    def __init__(self, message, bar_length=30):
-        self.message = message
+    def __init__(self, bar_length=30):
         self.stop_flag = None
         self.loader_thread = None
         self.progress = 0
@@ -23,7 +22,7 @@ class Loader:
     def loader(self):
         while not self.stop_flag:
             progress_bar = self.progress_bar()
-            sys.stdout.write(f"\r{self.message} [{progress_bar}]")
+            sys.stdout.write(f"\r[{progress_bar}]")
             sys.stdout.flush()
             if self.progress >= self.bar_length:
                 break
@@ -38,28 +37,20 @@ class Loader:
         empty = bar_length - filled
         filled_bar = Fore.RED + '-' * filled + Style.RESET_ALL
         empty_bar = Fore.LIGHTBLACK_EX + '-' * empty + Style.RESET_ALL
-        progress_bar = f"{filled_bar}{empty_bar}"
-        
         # Eğer bar dolarsa animasyon başlat
         if self.progress >= bar_length:
             animation = "/" if self.progress % 2 == 0 else "\\"
-            progress_bar = f"[{Fore.YELLOW} {animation}{Style.RESET_ALL}]{progress_bar[2:]}"
+            progress_bar2 = f"{progress_bar[2:]}[{Fore.YELLOW}{animation}{Style.RESET_ALL}]"
+            return progress_bar2
+        else:
+            progress_bar = f"{filled_bar}{empty_bar}"
+            return progress_bar
+        
         
-        return progress_bar
 
 
 
-    def animate(self):
-        animation = ['/', '|', '\\', '-']
-        idx = 0
-        while not self.stop_flag:
-            sys.stdout.write(f"\r{self.message} [{Fore.YELLOW}{animation[idx]}{Style.RESET_ALL}]")
-            sys.stdout.flush()
-            idx = (idx + 1) % len(animation)
-            time.sleep(0.1)
 
-        sys.stdout.write('\r' + ' ' * (len(self.message) + self.bar_length + 4) + '\r')
-        sys.stdout.flush()
 
     
 class Process:
@@ -67,7 +58,7 @@ class Process:
         self.func = func
 
     def __call__(self, *args, **kwargs):
-        loader = Loader("Loading...")
+        loader = Loader()
         loader.start()
         result = self.func(*args, **kwargs)
         loader.stop()
